@@ -2,7 +2,7 @@
 /**
  * VFS API for abstracted file storage and access.
  *
- * Copyright 2002-2016 Horde LLC (http://www.horde.org/)
+ * Copyright 2002-2017 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.horde.org/licenses/lgpl21.
@@ -285,10 +285,11 @@ abstract class Horde_Vfs_Base
      *
      * @abstract
      *
-     * @param string $path         The path to store the file in.
-     * @param string $name         The filename to use.
-     * @param string $data         The file data.
-     * @param boolean $autocreate  Automatically create directories?
+     * @param string $path           The path to store the file in.
+     * @param string $name           The filename to use.
+     * @param string|resource $data  The data as a string or stream resource.
+     *                               Resources allowed  @since  2.4.0
+     * @param boolean $autocreate    Automatically create directories?
      *
      * @throws Horde_Vfs_Exception
      */
@@ -751,7 +752,7 @@ abstract class Horde_Vfs_Base
                 throw new Horde_Vfs_Exception('Unable to read VFS file (filesize() failed).');
             }
         } else {
-            $filesize = strlen($data);
+            $filesize = $this->_getDataSize($data);
         }
         $oldsize = 0;
         if ($name) {
@@ -772,6 +773,45 @@ abstract class Horde_Vfs_Base
         }
     }
 
+    /**
+     * Return the size of $data.
+     *
+     * @param string|resource  $data  The data.
+     *
+     * @return integer  The data length.
+     */
+    protected function _getDataSize($data)
+    {
+        if (is_resource($data)) {
+            $pos = fseek($data, 0, SEEK_END);
+            $size = ftell($data);
+            fseek($data, $pos);
+
+            return $size;
+        }
+
+        return strlen($data);
+    }
+
+    protected function _ensureSeekable($stream)
+    {
+        if (!is_resource($stream)) {
+            return $stream;
+        }
+
+        $meta = stream_get_meta_data($stream);
+        if (!$meta['seekable']) {
+            $temp = @fopen('php://temp', 'r+');
+            while (!feof($stream)) {
+                fwrite($temp, fread($stream, 8192));
+            }
+            return $temp;
+        }
+
+        rewind($stream);
+        return $stream;
+    }
+
     /**
      * Checks the quota when preparing to delete data.
      *
