@@ -59,7 +59,9 @@ class Horde_Vfs_SqlFile extends Horde_Vfs_File
     {
         /* No need to check quota here as we will check it when we call
          * writeData(). */
-        $data = file_get_contents($tmpFile);
+        if (!$data = @fopen($tmpFile, 'rb')) {
+            throw new Horde_Vfs_Exception('Unable to open ' . $tmpFile);
+        }
         return $this->writeData($path, $name, $data, $autocreate);
     }
 
@@ -75,6 +77,7 @@ class Horde_Vfs_SqlFile extends Horde_Vfs_File
      */
     public function writeData($path, $name, $data, $autocreate = false)
     {
+        $data = $this->_ensureSeekable($data);
         $this->_checkQuotaWrite('string', $data, $path, $name);
 
         $fp = @fopen($this->_getNativePath($path, $name), 'w');
@@ -89,6 +92,9 @@ class Horde_Vfs_SqlFile extends Horde_Vfs_File
                 throw new Horde_Vfs_Exception('Unable to open VFS file for writing.');
             }
         }
+        if (is_resource($data)) {
+            rewind($data);
+        }
 
         if (!@fwrite($fp, $data)) {
             throw new Horde_Vfs_Exception('Unable to write VFS file data.');
