@@ -101,7 +101,7 @@ class Horde_Vfs_Ssh2 extends Horde_Vfs_Base
         $this->_connect();
 
         $statinfo = @ssh2_sftp_stat($this->_sftp, $this->_getPath($path, $name));
-        if ( ($statinfo === false) or (($size = $statinfo['size']) === false) ) {
+        if (($statinfo === false) || (($size = $statinfo['size']) === false)) {
             throw new Horde_Vfs_Exception(sprintf('Unable to check file size of "%s".', $this->_getPath($path, $name)));
         }
 
@@ -260,7 +260,7 @@ class Horde_Vfs_Ssh2 extends Horde_Vfs_Base
         /* See if we can stat the remote filename. ANDed with 040000 is true
          * if it is a directory. */
         $statinfo = @ssh2_sftp_stat($this->_sftp, $this->_getPath($path, $name));
-        return ( $statinfo !== false ) and ( $statinfo['mode'] & 040000 );
+        return ($statinfo !== false) && ($statinfo['mode'] & 040000 === 040000);
     }
 
     /**
