@@ -2,7 +2,7 @@
 /**
  * Test the file based virtual file system.
  *
- * Copyright 2008-2016 Horde LLC (http://www.horde.org/)
+ * Copyright 2008-2017 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.horde.org/licenses/lgpl21.
@@ -189,6 +189,11 @@ class Horde_Vfs_FileTest extends Horde_Vfs_TestBase
         $this->_chmod();
     }
 
+    public function testNullRoot()
+    {
+        $this->_nullRoot();
+    }
+
     public function testDeleteUnusalFileNames()
     {
         $file = '高&执&行&力&的&打&造.txt';
