@@ -1,6 +1,6 @@
 <?php
 /**
- * Copyright 2013-2016 Horde LLC (http://www.horde.org/)
+ * Copyright 2013-2017 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.horde.org/licenses/lgpl21.
@@ -181,6 +181,11 @@ class Horde_Vfs_MongoTest extends Horde_Vfs_TestBase
         $this->_listFolder();
     }
 
+    public function testNullRoot()
+    {
+        $this->_nullRoot();
+    }
+
     public static function setUpBeforeClass()
     {
         if (($config = self::getConfig('VFS_MONGO_TEST_CONFIG', __DIR__)) &&
