@@ -2,7 +2,7 @@
 /**
  * Test the SSH based virtual file system.
  *
- * Copyright 2012-2016 Horde LLC (http://www.horde.org/)
+ * Copyright 2012-2017 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.horde.org/licenses/lgpl21.
@@ -165,6 +165,11 @@ class Horde_Vfs_Ssh2Test extends Horde_Vfs_TestBase
         $this->_chmod();
     }
 
+    public function testNullRoot()
+    {
+        $this->_nullRoot();
+    }
+
     public static function setUpBeforeClass()
     {
         if (!extension_loaded('ssh2')) {
